summaryrefslogtreecommitdiff
path: root/include/apr_md5.h
diff options
context:
space:
mode:
authordougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2000-08-02 05:26:45 +0000
committerdougm <dougm@13f79535-47bb-0310-9956-ffa450edef68>2000-08-02 05:26:45 +0000
commit8fcf6e0fadd7ec31d02e7249dc69922b24747c11 (patch)
tree4da0bfd73d36292921960aaabc877a57e680b8c4 /include/apr_md5.h
parent5198c260c1982414023e984799ce1c3b04bb6b43 (diff)
downloadlibapr-8fcf6e0fadd7ec31d02e7249dc69922b24747c11.tar.gz
prefix libapr functions and types with apr_
git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@60470 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_md5.h')
-rw-r--r--include/apr_md5.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/include/apr_md5.h b/include/apr_md5.h
index 774bfef11..412f1a7a1 100644
--- a/include/apr_md5.h
+++ b/include/apr_md5.h
@@ -107,26 +107,26 @@ typedef struct {
UINT4 count[2]; /* number of bits, modulo 2^64 (lsb first) */
unsigned char buffer[64]; /* input buffer */
#if APR_HAS_XLATE
- ap_xlate_t *xlate; /* translation handle */
+ apr_xlate_t *xlate; /* translation handle */
#endif
} ap_md5_ctx_t;
/**
* MD5 Initialize. Begins an MD5 operation, writing a new context.
* @param context The MD5 context to initialize.
- * @deffunc ap_status_t ap_MD5Init(ap_md5_ctx_t *context)
+ * @deffunc apr_status_t apr_MD5Init(ap_md5_ctx_t *context)
*/
-APR_EXPORT(ap_status_t) ap_MD5Init(ap_md5_ctx_t *context);
+APR_EXPORT(apr_status_t) apr_MD5Init(ap_md5_ctx_t *context);
/**
* MD5 translation setup. Provides the APR translation handle to be used
* for translating the content before calculating the digest.
* @param context The MD5 content to set the translation for.
* @param xlate The translation handle to use for this MD5 context
- * @deffunc ap_status_t ap_MD5SetXlate(ap_md5_ctx_t *context, ap_xlate_t *xlate)
+ * @deffunc apr_status_t ap_MD5SetXlate(ap_md5_ctx_t *context, apr_xlate_t *xlate)
*/
#if APR_HAS_XLATE
-APR_EXPORT(ap_status_t) ap_MD5SetXlate(ap_md5_ctx_t *context, ap_xlate_t *xlate);
+APR_EXPORT(apr_status_t) ap_MD5SetXlate(ap_md5_ctx_t *context, apr_xlate_t *xlate);
#else
#define ap_MD5SetXlate(context, xlate) APR_ENOTIMPL
#endif
@@ -137,9 +137,9 @@ APR_EXPORT(ap_status_t) ap_MD5SetXlate(ap_md5_ctx_t *context, ap_xlate_t *xlate)
* @param context The MD5 content to update.
* @param input next message block to update
* @param inputLen The length of the next message block
* @deffunc ap_status_t ap_MD5Update(ap_md5_ctx_t *context, const unsigned char *input, unsigned int inputLen)
*/
-APR_EXPORT(ap_status_t) ap_MD5Update(ap_md5_ctx_t *context,
+APR_EXPORT(apr_status_t) apr_MD5Update(ap_md5_ctx_t *context,
const unsigned char *input,
unsigned int inputLen);
@@ -148,9 +148,9 @@ APR_EXPORT(ap_status_t) ap_MD5Update(ap_md5_ctx_t *context,
* message digest and zeroing the context
* @param digest The final MD5 digest
* @param context The MD5 content we are finalizing.
- * @deffunc ap_status_t ap_MD5Final(unsigned char digest[MD5_DIGESTSIZE], ap_md5_ctx_t *context)
+ * @deffunc apr_status_t apr_MD5Final(unsigned char digest[MD5_DIGESTSIZE], ap_md5_ctx_t *context)
*/
-APR_EXPORT(ap_status_t) ap_MD5Final(unsigned char digest[MD5_DIGESTSIZE],
+APR_EXPORT(apr_status_t) apr_MD5Final(unsigned char digest[MD5_DIGESTSIZE],
ap_md5_ctx_t *context);
/**
@@ -159,9 +159,9 @@ APR_EXPORT(ap_status_t) ap_MD5Final(unsigned char digest[MD5_DIGESTSIZE],
* @param salt The salt to use for the encoding
* @param result The string to store the encoded password in
* @param nbytes The length of the string
* @deffunc ap_status_t ap_MD5Encode(const char *password, const char *salt, char *result, size_t nbytes)
*/
-APR_EXPORT(ap_status_t) ap_MD5Encode(const char *password, const char *salt,
+APR_EXPORT(apr_status_t) apr_MD5Encode(const char *password, const char *salt,
char *result, size_t nbytes);
#ifdef __cplusplus
@@ -137,9 +137,9 @@ APR_EXPORT(ap_status_t) ap_MD5SetXlate(ap_md5_ctx_t *context, ap_xlate_t *xlate)
* @param input next message block to update
* @param inputLen The length of the next message block
- * @deffunc ap_status_t ap_MD5Update(ap_md5_ctx_t *context, const unsigned char *input, unsigned int inputLen)
+ * @deffunc apr_status_t apr_MD5Update(ap_md5_ctx_t *context, const unsigned char *input, unsigned int inputLen)
*/
@@ -159,9 +159,9 @@ APR_EXPORT(ap_status_t) ap_MD5Final(unsigned char digest[MD5_DIGESTSIZE],
* @param result The string to store the encoded password in
* @param nbytes The length of the string
- * @deffunc ap_status_t ap_MD5Encode(const char *password, const char *salt, char *result, size_t nbytes)
+ * @deffunc apr_status_t apr_MD5Encode(const char *password, const char *salt, char *result, size_t nbytes)
*/